@@ -1,11 +1,12 @@
 package Perinci::Object;
 
+our $DATE = '2014-10-16'; # DATE
+our $VERSION = '0.14'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.12'; # VERSION
-
 require Exporter;
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(rimeta risub rivar ripkg envres riresmeta);
@@ -16,18 +17,18 @@ sub rimeta {
 }
 
 sub risub {
-    require Perinci::Object::function;
-    Perinci::Object::function->new(@_);
+    require Perinci::Object::Function;
+    Perinci::Object::Function->new(@_);
 }
 
 sub rivar {
-    require Perinci::Object::variable;
-    Perinci::Object::variable->new(@_);
+    require Perinci::Object::Variable;
+    Perinci::Object::Variable->new(@_);
 }
 
 sub ripkg {
-    require Perinci::Object::package;
-    Perinci::Object::package->new(@_);
+    require Perinci::Object::Package;
+    Perinci::Object::Package->new(@_);
 }
 
 sub envres {
@@ -36,8 +37,8 @@ sub envres {
 }
 
 sub riresmeta {
-    require Perinci::Object::result;
-    Perinci::Object::result->new(@_);
+    require Perinci::Object::ResMeta;
+    Perinci::Object::ResMeta->new(@_);
 }
 
 1;
@@ -55,7 +56,7 @@ Perinci::Object - Object-oriented interface for Rinci metadata
 
 =head1 VERSION
 
-version 0.12
+This document describes version 0.14 of Perinci::Object (from Perl distribution Perinci-Object), released on 2014-10-16.
 
 =head1 SYNOPSIS
 
@@ -125,22 +126,23 @@ Exported by default. A shortcut for Perinci::Object::Metadata->new($meta).
 
 =head2 risub $meta => OBJECT
 
-Exported by default. A shortcut for Perinci::Object::function->new($meta).
+Exported by default. A shortcut for Perinci::Object::Function->new($meta).
 
 =head2 rivar $meta => OBJECT
 
-Exported by default. A shortcut for Perinci::Object::variable->new($meta).
+Exported by default. A shortcut for Perinci::Object::Variable->new($meta).
 
 =head2 ripkg $meta => OBJECT
 
-Exported by default. A shortcut for Perinci::Object::package->new($meta).
+Exported by default. A shortcut for Perinci::Object::Package->new($meta).
 
-=head2 riresmeta $res => OBJECT
+=head2 envres $res => OBJECT
 
-Exported by default. A shortcut for Perinci::Object::Result->new($res).
+Exported by default. A shortcut for Perinci::Object::EnvResult->new($res).
 
+=head2 riresmeta $resmeta => OBJECT
 
-None are exported by default, but they are exportable.
+Exported by default. A shortcut for Perinci::Object::ResMeta->new($res).
 
 =head1 SEE ALSO
 
@@ -164,11 +166,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
